package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"(```````!``````````""Q````
M`````````$``.``+`$``&@`9``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````'`:````````<!H`````````
M$`````````$````%`````"``````````(``````````@````````C3L`````
M``"-.P`````````0`````````0````0`````8`````````!@`````````&``
M``````#81````````-A$`````````!`````````!````!@```,"K````````
MP+L```````#`NP```````&`$````````X!0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)T```````"`G0``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#`JP```````,"[````````P+L```````!`!````````$`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`'A9^Z,$P&@6.":$<V:.VYVCU.7`!````!`````!````1TY5```````#
M`````@`````````]````0`````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(01;H``@H``````````$``````````00```$,```!%````````
M`$8`````````1P```$@```!)````2P``````````````3```````````````
M``````````````````````````!-````3@```%````!2````````````````
M````4P````````!4`````````%4``````````````%8```!7`````````%@`
M``!9````````````````````6@````````!;``````````````!<````70``
M`%\``````````````&``````````````````````````N^.2?*;=HVMK&IY0
M+L6;MD/ZUX<5C"7,9Z_,9F_%WQ^)!W#3Q(D%D*/@^TG[H6Q@U634?,/E/RQ^
MJ9R;K4OCP.)'Q@'/WD<M#13BGB'_Y`[AIP(*V\WCG@N*$%>S`8MO#3J7"]EQ
M6!Q7I)N6,V+;[6L)0];$N9Q`.?*+'$-%U>QK?YI\````````````````````
M````````````&@$``!(`````````````````````````B@$``!(`````````
M````````````````Y`$``!(`````````````````````````P@$``!(`````
M`````````````````````0```"``````````````````````````ZP$``!(`
M````````````````````````=P(``!(```````````````````````````(`
M`!(`````````````````````````EP```!(`````````````````````````
M7P(``!(`````````````````````````5P(``!(`````````````````````
M````V````!(`````````````````````````2@,``!(`````````````````
M````````%0$``!(`````````````````````````(P(``!(`````````````
M````````````%0(``!(`````````````````````````TP$``!(`````````
M````````````````<`(``!(`````````````````````````@`(``!(`````
M````````````````````YP```!(`````````````````````````NP```!(`
M````````````````````````]0```!(`````````````````````````MP$`
M`!(`````````````````````````R@$``!(`````````````````````````
MX`(``!(`````````````````````````'P$``!(`````````````````````
M````^0$``!(`````````````````````````A0$``!(`````````````````
M````````Q`(``!(`````````````````````````O0(``!(`````````````
M````````````4P```!(`````````````````````````'0```"``````````
M````````````````-P(``!(`````````````````````````,@$``!(`````
M````````````````````HP$``!(`````````````````````````*P$``!(`
M````````````````````````@````!(```````````````````````````$`
M`!(`````````````````````````C````!(`````````````````````````
M4@$``!(`````````````````````````90$``!(`````````````````````
M````8P```!(`````````````````````````/@(``!(`````````````````
M````````L````!(`````````````````````````00$``!(`````````````
M````````````\0$``!(`````````````````````````?@$``!(`````````
M````````````````K@(``!(`````````````````````````AP(``!(`````
M````````````````````;P```!(`````````````````````````M@(``!(`
M````````````````````````#@(``!(`````````````````````````R0``
M`!(`````````````````````````IP```!(`````````````````````````
M3`(``!(`````````````````````````O0$``!(`````````````````````
M````FP$``!(`````````````````````````*0(``!(`````````````````
M````````+````"``````````````````````````!P(``!(`````````````
M````````````D0(``"(`````````````````````````'`(``!(`````````
M````````````````H`(``!(`````````````````````````XP,``!``%P"@
MT```````````````````V`(``"$`%P!`P`````````@`````````]0,``!(`
M#0#P6````````/L!````````)P,``!(`#0#@*P````````4`````````C`,`
M`!(`#0!`5P```````*<!````````0`0``!(`#0#@5@```````%4`````````
M<P,``!(`#0`P+@```````!T`````````4P,``!(`#0"`/P```````#\!````
M````V0,``!$`%@`8P`````````@`````````UP(``"$`%P!`P`````````@`
M````````Z`,``!(`#0!0+@```````*<$````````(`0``!(`#0"@,P``````
M`!`!````````200``!(`#0#`/````````+$"````````"P0``!(`#0#0*@``
M`````#(`````````.`,``!(`#0"`,P```````!\`````````I`,``!$`#P``
M8`````````0`````````9@,``!(`#0``+@```````"4`````````?P,``!(`
M#0"P-`````````$(````````%P,``!(`#0!@6P````````4`````````$P0`
M`!(`#0#P*P````````4"````````LP,``!(`#0`0*P```````,4`````````
MR0,``!(`#0#P6@```````&4`````````1@```!$`%P`PP`````````$`````
M````,@0``!(`#0``,P```````'4`````````F0,``"``%@``P```````````
M````````_P,``!``%P`@P```````````````````<P$``!$`%P`@P```````
M``0`````````G0,``!(`#0!@(@```````"\`````````EP,``!``%@``P```
M````````````````U@(``!$`%P!`P`````````@`````````:0(``!$`%P!@
MP`````````@`````````7P,``!``%@`@P```````````````````T0(``!(`
M#0!`(````````!X"`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,
M7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H<'8`4&5R;%]M9U]S970`4&5R;%]A
M=&9O<FM?;&]C:P!097)L7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?1'EN84QO
M861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`4&5R;%]S
M=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T<G5C=`!P97)L7V%L
M;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L7W-A9F5S
M>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y`&]P96XV
M-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`
M7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`&QI8G!E<FPN<V\`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!?
M7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`'!A<E]I;FET7V5N=@!S:&%?
M9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA
M;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ
M-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XS,B]C
M;W)E7W!E<FPO0T]210`````"``,``@`"`````@`"``(````"``(````"````
M`@`"``0``@`"``````````,``@`%`````@`#``(``@``````!@````,``@``
M```````````````'```````"``,``@`"`````@`"```````"``(``P`'````
M`@`"``(`!P`!``(``0`!``$``0`!``$``0`"``$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!``$````!``$``@`"``$``0````$``0#]`@``$````"``
M``!U&FD)```#`%\$`````````0`%``T#```0`````````'09:0D```<`:P0`
M`!````"4D98&```&`'<$```0````<AEI"0``!0""!```$````!1I:0T```0`
MC@0``!````!U&FD)```"`%\$````````P+L````````(`````````%`C````
M````R+L````````(```````````C````````",`````````(``````````C`
M````````&,`````````(`````````.!B````````$+X````````&`````0``
M````````````&+X````````&`````@``````````````(+X````````&````
M`P``````````````*+X````````&````!```````````````,+X````````&
M````!0``````````````.+X````````&````!@``````````````0+X`````
M```&````!P``````````````2+X````````&````"```````````````4+X`
M```````&````"0``````````````6+X````````&````"@``````````````
M8+X````````&````"P``````````````:+X````````&````#```````````
M````<+X````````&````#0``````````````>+X````````&````#@``````
M````````@+X````````&````#P``````````````B+X````````&````$```
M````````````D+X````````&````$0``````````````F+X````````&````
M$@``````````````H+X````````&````$P``````````````J+X````````&
M````%```````````````L+X````````&````%0``````````````N+X`````
M```&````%@``````````````P+X````````&````%P``````````````R+X`
M```````&````&```````````````T+X````````&````&@``````````````
MV+X````````&````&P``````````````X+X````````&````'```````````
M````Z+X````````&````'0``````````````\+X````````&````'@``````
M````````^+X````````&````'P```````````````+\````````&````(```
M````````````"+\````````&````(0``````````````$+\````````&````
M(@``````````````&+\````````&````(P``````````````(+\````````&
M````)```````````````*+\````````&````)0``````````````,+\`````
M```&````)@``````````````.+\````````&````)P``````````````0+\`
M```````&````*```````````````2+\````````&````*0``````````````
M4+\````````&````*@``````````````6+\````````&````*P``````````
M````8+\````````&````+```````````````:+\````````&````+0``````
M````````<+\````````&````+@``````````````>+\````````&````+P``
M````````````@+\````````&````,```````````````B+\````````&````
M,0``````````````D+\````````&````,@``````````````F+\````````&
M````,P``````````````H+\````````&````-```````````````J+\`````
M```&````-0``````````````L+\````````&````-@``````````````N+\`
M```````&````-P``````````````P+\````````&````.```````````````
MR+\````````&````.0``````````````T+\````````&````.@``````````
M````V+\````````&````.P``````````````X+\````````&````/```````
M````````Z+\````````&````/0``````````````\+\````````&````/@``
M````````````^+\````````&````/P``````````````(,`````````%````
M6@``````````````,,`````````%````5@``````````````0,`````````%
M````70``````````````8,`````````%````7@``````````````"+X`````
M```'````&0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!?&>``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@____05152(/L.(E\)!Q(C7PD'$B)="002(UT
M)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP/\5EIX``$B+-;^>``!(BST(
MGP``2(GR9^C?.@``@#V8GP```'4R_Q48G@``2(D%\:\``$B)QTB%P`^$F@$`
M`/\5KYT``(L]89\``/\54YX``,:`Z0D```"+/4Z?``#_%4">``"+/4*?``"`
MB#H$```"_Q4MG@``@(@Z!````8M$)!R->`1$C6`#2&/_2,'G`_\5QIT``$B+
M3"00BW0D'$F)P4B)!7.O``!(BP%)B0%(C06B0```28E!"$B+!>.>``!)B4$0
M2(T%CT```$F)01B#_@$/CO8```!(@\$(@\8#N`0````/'X``````2(LY2&/0
M@\`!2(/!"$F)/-$YQG7K2&/V2,'F`T2)XDB+/1*O``!%,<!,B<E)QP0Q````
M`$B--<4(``#_%;^=``!!B<2%P'162(UL)"1(BSWDK@``_Q7NG```,<!(B>Y(
MC3W=/@``Z)4!``!(A<!T0$B+/<&N``#_%9N<``#_%66=``!(BT0D*&1(*P0E
M*````'5E2(/$.$2)X%U!7,-(BSV3K@``_Q6EG0``08G$ZYA(BSUQK@``2(7_
M=`?H7QT``.NM2(T],#X``$B)[N@N`0``2(D%3ZX``$B)QTB%P'2/Z]F^(```
M`.DO____OP$```#_%6B=``#_%3*<``!FD/,/'OHQ[4F)T5Y(B>)(@^3P4%1,
MC07F.```2(T-;S@``$B-/;C]____%5J<``#TD$B-/8F=``!(C06"G0``2#GX
M=!5(BP6&FP``2(7`=`G_X`\?@`````###Q^``````$B-/5F=``!(C352G0``
M2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!>V<``!(A<!T"/_@9@\?1```PP\?
M@`````#S#Q[Z@#U=G0```'4S54B#/=*<````2(GE=`U(BSWFG```_Q7`G```
MZ&/____&!32=```!7<-F+@\?A```````PV9F+@\?A```````#Q]``/,/'OKI
M9____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R++<*<``!-A>T/
MA*$````/M@=)B?](B?6$P'0$/#UU6$4Q]DV+90!-A>1T,TUC]DR)ZV8/'T0`
M`$R)\DR)_DR)Y_\5:9H``(7`=0=#@#PT/71&3(MC"$B#PPA-A>1UV4B#Q`A,
MB>!;74%<05U!7D%?PP\?@`````!)B?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN2
M#Q^``````$PIZT^-9#0!2,'[`XE=`.NV#Q^``````$4QY.NJ#Q\`059!54%4
M55-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=3%(BX0D
MF````&1(*P0E*`````^%00$``$B!Q*````!;74%<05U!7L-F+@\?A```````
M_Q7*F0``28G$2(7`=,%)B>5,B>?_%=Z:``!(A<`/A+T```"`>!,N2(U8$W4+
M@'L!`'3>#Q]$``"`>!,N#X2^````2(GO_Q6MF0``2(G?28G&_Q6AF0``08U\
M!@)(8___%2N:``!)B=E)B>B^`0```$F)QDB)QS'`2,?"_____TB-#>XZ``#_
M%=R:``"_`0```$R)ZDR)]O\5*YD``$R)]X/X_W00BT0D&"4`\```/0!```!T
M:_\5U9@``$R)]_\5O)@``$R)Y_\5*YH``$B%P`^%3?___V8N#Q^$``````!,
MB>?_%4^9``!(B>__%?Z8``#IV/[__V8/'X0``````(![`2X/A3C___^`>P(`
M#X3]_O__Z2G___\/'X``````Z'O^___KE/\5TY@```\?`%5(B?Y(B?V_`0``
M`$B![*````!D2(L$)2@```!(B80DF````#'`2(GB_Q7)F0``A<!U-8M4)!B!
MX@#P``"!^@!```!T"('Z`*```'4=O@(```!(B>__%7V9``"%P`^4P`^VP.L%
M#Q\`,<!(BXPDF````&1(*PPE*````'4)2('$H````%W#_Q5$F```#Q]``%5(
MB?W_%2Z8``!(C50%_T@YU7(5Z9$````/'X``````2(/J`4@YU70E@#HO=/)(
M.=5S=TB#Z@%(.=5T$@\?0`"`.B]T*$B#Z@%(.=5U\H!]`"]T9$B-/6$Y``!=
M_R4NF0``9@\?1```@#HO=0E(@^H!2#G5<O)(*>HQP$B-2@)(@?D`$```=R!(
M@\(!N0`0``!(B>Y(C3V5F0``_Q5GF```2(T%B)D``%W#2#G5=;[KG0\?@```
M``!(C3W[.```7?\ERI@``&8N#Q^$``````!!5[K_#P``059!54%428GT54B)
M_4B-/=,X``!(@>P0$```9$B+!"4H````2(F$)`@0```QP$F)Y4R)[O\5WY8`
M`(7`?GN-4/]$BSVQF```3&/R0H`\-`!U7X72=&I,B?*^+P```$R)[_\52I<`
M`$B%P'141(G__Q5\EP``3(GQ3(GJ2(GN2(G'_Q7ZEP``2(N$)`@0``!D2"L$
M)2@```!U0$B!Q!`0``!=05Q!74%>05_#9@\?1```3&/PZZ`/'P!$BSTYF```
M1(G__Q4HEP``3(GB2(GN2(G'_Q6QE@``ZZW_%8F6``!F#Q^$``````!!5T%6
M055!5%5(B?532(G[2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!Q4B)
M[_\50)8``$B-="0$2(G?28G$,<#H!OO__TB%P`^$#0$``$F)Q4B)Q_\5&98`
M`$DYQ`^&V````$QC="0$2<'F`P^V`X3`#X2L`0``/#T/A*0!``!(B=AF#Q^$
M```````/ME`!2(/``832=`6`^CUU[T@IV$B83`,U@Y<``$J-?"`"_Q58E@``
M28D&2(7`=%E(BP5IEP``2&-4)`1(C4L!2(L4T`^V`X@"A,!T(#P]=0OK&@\?
M1```A,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(
M@\`!A,EU[TB+1"0(9$@K!"4H````#X4/`0``2(/$&%M=05Q!74%>05_##Q]`
M`#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(L]R98``$F#/P`/
MA+X```!,B?A%,>UF#Q^$``````!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!
MY@.+!<^F``"%P'5;QP7!I@```0```$B)]_\56)4``$B%P`^$6/___TUC]4R)
M_DB)QTG!Y@-,B?+_%9F5``!(B052E@``2(G!08U%`4B82,<$P0````!$B6PD
M!.EX_O__#Q^``````$R)__\55Y4``$B)!2"6``!(B<%(A<`/A/W^__]-8_5)
MP>8#Z[P/'P`QP.EW_O__OA````!%,>WI7_____\5/I0``&9F+@\?A```````
M#Q\`2(/L"(L]MI4``/\5J)0``(L]JI4``/\5G)0``$B+%<V3``!(C0V^<@``
M2(TUC#4``$B)Q_\5GI0``(L]@)4``/\5<I0``$R-!?PV``!%,<E(C14)$@``
M2(G'3(G!2(TU=34``$B#Q`C_)9J4``!FD$B#[`B+/4:5``#_%3B4``!(BQ5I
MDP``2(/$"$B-#59R``!(B<=(C34A-0``_R4VE```9F8N#Q^$```````/'P!!
M5%532('L("```&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```/\5"9,`
M`$R-#=,T``"Z`1```$B)[T&)P$B-#?8T``"^`0```#'`_Q63E```N@`0``!,
MB>9(B>__%<J2``!%,<"%P'@PC7@!2(G#2&/__Q64DP``28G`2(7`=!E(8]M,
MB>9(B<=(B=K_%6*3``#&!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@
M``!,B<!;74%<P_\5NY(``&9F+@\?A```````Z2O___]F9BX/'X0``````$%7
M059!54F)]4%454B)_4B-/50T``!32('LN!```&1(BP0E*````$B)A"2H$```
M,<!(C70D#.@U]___OB\```!(B>](B</_%622``!(A<!T/S'`2(GN2(T]%C0`
M`.B^^___2(GH2(N<)*@0``!D2"L<)2@````/A8,!``!(@<2X$```6UU!7$%=
M05Y!7\-FD$B)[_\5_Y$``$B-->`S``!,B>]!B<3_%023``!)B<9(A<!TG4&`
M/@!,C2U;,P``#X3?````#Q\`2(7;=!1,B?9(B=__%2>2``"%P`^$G@```$R)
M]_\5KI$``(U0_XG!2&/"3`'P@#@O=1EF#Q]$``")T8/J`<8``$ACPDP!\(`X
M+W3M0HU$(0$]_P\```^/+O___TV)\+H`$```O@$````QP$R-O"2@````2(/L
M"$B-#2\T``!53(T-SS(``$R)__\5LI(``$R)_K\!````2(U4)"#_%?^0``!:
M687`=1"+1"0H)0#P```]`(```'112(TU^C(``#'__Q4BD@``28G&2(7`#X2W
M_O__08`^``^%)/___TB%VW0%@#LN=!)-B>ZY`0```.E8____#Q]$``"`>P$`
M=+GKY@\?A```````O@$```!,B?__%<J1``"%P'6=3(G^2(T]AS(``.@O^O__
M3(G__Q7VD0``Z6;^____%9N0``!F9BX/'X0```````^V!TF)^(3`=!=F#Q]$
M``!(@\<!/"\/M@=,#T3'A,!U[TR)P,-F9BX/'X0``````$B%_W0+@#\`=`;I
M$?C__Y!(C3W#,0``_R63D0``#Q\`55-(C1T9,@``2(/L2&8/;P7[;@``9$B+
M!"4H````2(E$)#@QP#'`2(UL)`P/$40D$&8/;P7G;@``9HE$)#`/$40D(`\?
M1```,<!(B>Y(B=_HN_3__TB%P'0^2&-4)`Q(BP6*D0``2(T$T$B+4`A(B1!(
MA=)TTF8N#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1V,,0``
MD#'`2(GN2(G?Z&/T__](A<!T-DAC5"0,2(L%,I$``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'40Q``"0,<!(B>Y(B=_H
M$_3__TB%P'0V2&-4)`Q(BP7BD```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```2(T=_3```)`QP$B)[DB)W^C#\___2(7`=#9(
M8U0D#$B+!9*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7P
MZ[YF#Q]$``!(C1VT,```D#'`2(GN2(G?Z'/S__](A<!T-DAC5"0,2(L%0I``
M`$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-
M'70P``"0,<!(B>Y(B=_H(_/__TB%P'0V2&-4)`Q(BP7RCP``2(T$T$B+4`A(
MB1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=VR\``)`QP$B)
M[DB)W^C3\O__2(7`=#9(8U0D#$B+!:*/``!(C0302(M0"$B)$$B%TG329I!(
MBU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1W@+P``D#'`2(GN2(G?Z(/R__](
MA<!T-DAC5"0,2(L%4H\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D0
M2(72=?#KOF8/'T0``$B-'9HO``"0,<!(B>Y(B=_H,_+__TB%P'0V2&-4)`Q(
MBP4"CP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?
M1```2(T=5"\``)`QP$B)[DB)W^CC\?__2(7`=#9(8U0D#$B+!;*.``!(C030
M2(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1VD+@``
MD#'`2(GN2(G?Z)/Q__](A<!T-DAC5"0,2(L%8HX``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)[DB-/;LN``#H2?'__TB)
MQDB%P'0.2(T]DRX``#'`Z./U__](B>Y(C3VG+@``,<#H(O'__TB)QDB%P'0.
M2(T]HRX``#'`Z+SU__](B>Y(C3V=+@``,<#H^_#__TB)QDB%P'0Z2(T]YBT`
M`#'`Z)7U__\QP$B--48O``!(C3T(+@``Z(#U__](BT0D.&1(*P0E*````'51
M2(/$2%M=PTB)[DB-/5HN```QP.BH\/__2(G&2(7`=!!(C3WH+0``,<#H0O7_
M_^NK2+A005)?0TQ%04@Y1"0A=9IF@7PD*4X]=9%(C70D*^O/_Q69BP``9@\?
MA```````2(/L&&1(BP0E*````$B)1"0(BP7XC```@_C_=!M(BWPD"&1(*SPE
M*````'5"2(/$&,-F#Q]$``!(C70D!$B-/6LM```QP.@5\/__2(G",<!(A=)T
M$@^V$H#Z,`^5P3'`A-(/E<`AR(D%HXP``.NN_Q4;BP``9F8N#Q^$``````!(
M@^P(_Q4.BP``B<?_%=Z*``!(A<!T`TB+`$B#Q`C#D$%454B)_4B-/7HM``!3
M2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.B4[___2(7`=`B`.`!(B<-U-TB+
M1"0(9$@K!"4H````#X6]````2(GN2(/$$$B-/2PM```QP%M=05SI"O3__V8N
M#Q^$``````!(B>Y(B<?_%=2+``!(A<!T'TB+1"0(9$@K!"4H````=7E(@\00
M6UU!7,-F#Q]$``!(B>__%3^*``!(B=])B<3_%3.*``!)C7P$`O\5P(H``$B#
M[`A)B>B^`0```%-(Q\+_____2(G'28G$3(T-[RL``$B-#=PL```QP/\5:(L`
M`%A:2(M$)`AD2"L$)2@```!U"$R)YNE&_____Q7@B0``05=!5D%528G]2(T]
MFBL``$%455-(@>R(@0``9$B+!"4H````2(F$)'B!``!(C05@+```3(UD)!Q(
MQT0D,`````!(QX0DB`````````!,B>9(QT0D4`````!(B40D($B-!?4J``!(
MB40D*$B-!<@K``!(B40D:$B-!1LL``!(B40D<$B-!<TK``!(B40D>$B-!0LL
M``!(B80D@````$B-!0`L``!(B40D2#'`Z`#N__](A<!T#(`X`$B)Q0^%KP0`
M`/\5(8D``(G'_Q7QB```2(7`#X3X`P``2(LH2(7M#X3L`P``2(GO_Q7KB```
M2(U\``'_%7B)``!$#[9%`$B)PT6$P'0W28G?3(TUGBL``)!(@\4!3(G_3(GQ
MO@$```!(Q\+_____,<!)@\<"_Q46B@``1`^V10!%A,!UU$R-="1@2(T]^"H`
M`.L79@\?1```28M^"$F#Q@A(A?\/A#\!``!,B>8QP.A%[?__2(G%2(7`=-V`
M.`!TV$B)Q^B0[___A<!TS$B)[_\5HXD``$F)QTB%P`^$!P$```\?@`````!,
MB?__%2^(``!(B=](B<7_%2.(``!$C;0%!`0``$UC]DR)]_\5IX@``%--B?A,
MC0V(*0``2(G%2(T%W2H``+X!````2,?"_____U!(C0W`*@``2(GO,<#_%4N)
M``!(B>^^P`$``/\5?8<``%]!6(/X_W43_Q5/AP``1(L(08/Y$0^%(`,``$B-
ME"20````2(GNOP$```#_%<R(``")PX7`#X2Z````28M-`$B+/5^)``!)B>@Q
MP$B-%0LK``"^`0```$4Q]O\5M8@``$B+A"1X@0``9$@K!"4H````#X5Y!0``
M2('$B($``$R)\%M=05Q!74%>05_#9@\?A```````2(ML)"!%,?;K$V8/'T0`
M`$ECQDB+;,0@2(7M=#N`?0``=#5(B>]!@\8!Z$'N__^%P'3=2(GO_Q54B```
M28G'2(7`#X6X_O__26/&2(MLQ"!(A>UUR`\?`$4Q_^F@_O__BX0DJ````"4`
M\```/0!````/A2____]$B[PDK````/\5PX8``$$YQP^%&/___XN$)*@````E
M_P$``#W``0``#X4!____3(GW_Q4BAP``2(T]+2D``$R)YDF)QC'`Z$[K__](
MB<=(A<`/A$("``#_%;R'``!)BWT`2(G&Z,#S__])B<=(A<`/A"0"``!,B?__
M%4.&``"#^`-^/DACT+D%````2(T]%RD``$F-=!?\\Z8/E\*`V@"$TG4>@_@$
M#X2)`P``@^@%2)A!@#P'+P^$>0,```\?1```BP6"AP``@_C_#X0I`P``A<`/
MA-0!``!(C34D*0``2(T]`B@``#'`Z%SO__],C27N*```3(TM2B<``/\5@(4`
M`$%428GHO@$```!02,?"_____TR)]S'`3(T-)B<``$B-#9PH``#_%06'``!8
M6NM-9@\?A```````_Q42A0``@S@1=4S_%3>%``"#PP%(@^P(38GI051)B>A(
MC0UP*```3(GW4TC'PO____^^`0```%`QP/\5N(8``$B#Q""^P`$``$R)]_\5
MYH0``(/X_W2I2(GO_Q6PA```3(GV2(T]\"8``#'`Z)_N__],B??H)_K__^F=
M_?__9I`QVTB-/:XG``#K$@\?1```2&/#2(M\Q$!(A?]T.4R)YC'`@\,!Z+;I
M__](A<!TX8`X`'3<2(G'_Q4CA@``2(G%2(7`#X7+^___2&/#2(M\Q$!(A?]U
MQ[\-````2(TM6B<``/\5.(4``$&X4P```$B)P^F_^___28M-`$B+/5^&``!)
MB>@QP$B-%<LG``"^`0```$4Q]O\5M84``.G[_/__2(G'Z'CY__](BX0D>($`
M`&1(*P0E*`````^%;`(``$B!Q(B!``!(B>];74%<05U!7D%?_R6'A0``#Q^`
M`````$V+?0#IT_W__\<%G84````````Q]DR)_S'`_Q7XA```08G$A<`/A!3^
M__](C9PD<`$``+H"````2,?&[O___XG'_Q4AA0``N@8```!(B=Y$B>?_%2B$
M``"`O"1P`0```'4.@+PD<0$``$,/A&\!```QTC'V1(GG_Q7KA```,<!GZ/L;
M``!)B<7K%&8/'T0``(G"2(G>3(GO9^A"'```N@"```!(B=Y$B>?_%=&#``"%
MP'_=3(V\)"`!``!$B>=,C24X)@``_Q65@P``3(GN3(G_3(VL)&@!``!GZ+$=
M``!(C80D0`$``$B)1"0(2(G#D$B)WTB#PP)%#[8'3(GA2,?"_____[X!````
M,<!)@\<!_Q6"A```23G===5(C04G)@``QH0D:`$```!0_W0D$$B-#>0E``!)
MB>A,B?<QP+X!````3(T-8B0``$C'PO______%4&$``!97NF9_?__9I`QP$R)
MYDB-/>,D``#HC^?__TB%P`^$C_[__P^V`(3`#X2$_O__/#`/A'S^___'!1F$
M```!````Z:/\__]-BVT(387M#X1__/__3(GO_Q5V@@``2(/X`P^&;/S__TF-
M=`7\N04```!(C3U()0``\Z8/E\`<`(3`30]$_>E)_/__@+PD<@$``$$/A8/^
M__^`O"1S`0``0P^%=?[__X"\)'0!``!(#X5G_O__@+PD=0$``$4/A5G^__^Z
M`@```$C'QL;___]$B>?_%3R#``"Z*0```$B)WD2)Y_\50X(``$B-!04E``!0
M4^GD_O___Q7?@0``9F8N#Q^$```````/'T``055!5%5(@^P0BSU1@P``9$B+
M!"4H````2(E$)`@QP/\5,X(``(L]-8,``$B)Q?\5)((```^VE;@```!(C6PD
M!$B-/8PC``!(B>Z(D+D````QP.A)YO__2(7`=`F`.#$/A,,!```QP.@D\?__
MBSWN@@``_Q7@@0``N0,```"Z`0```$B--5\D``!(B<?_%::!``!)B<1(A<!T
M.DB+0!"+/;R"``!,BRC_%:N!``!(C14V)```2(G'3(GN_Q4P@0``28M$)!!,
MBR!!]D0D#D`/A9P!``"+/8:"``#_%7B!``"Y`P```+H!````2(TU_B,``$B)
MQ_\5/H$``$F)Q$B%P'1`2(GN2(T]ER(``#'`Z(WE__])B<5(A<`/A"$!``!)
MBT0D$(L]-H(``$R+(/\5)8$``$R)ZDB)QTR)YO\5KH```(L]&((``/\5"H$`
M`+H!````2(TUER,``$B)Q_\5!8$``(L]]X$``$F)Q/\5YH```$R)YDB-%8HC
M``!(B<?_%6N```"+/=6!``#_%<>```!(B>Y(C3W_(0``QH"Y`````#'`Z/?D
M__](B048D@``28G$2(7`=$"^P`$``$R)Y_\5LG\``(U0`8/Z`78)@_@1#X6V
M````2(M$)`AD2"L$)2@````/A<````!(@\0074%<05W##Q\`2(L]T9$``.CL
M]?__2(D%O9$``$F)Q$B%P'6E2(T]EB,``#'`_Q5.@```9@\?1```@'@!``^$
M.O[__^DN_O__9@\?A```````2(L%B9$``(L]$X$``$R+*$F+1"003(L@_Q7Z
M?P``3(GN3(GGZ/?G___IU/[__V:0BSWJ@```_Q7<?P``3(GF2(G'_Q4(@```
MZ4?^__^)P4B+!3J1``!,B>)(C3TX(P``2(LP,<#_%<5_``#_%1]_``!F9BX/
M'X0```````\?0`!!5%5(B?U32(/L$&1(BP0E*````$B)1"0(,<!(A?\/A+P`
M``"`/P`/A+,```#HGN;__P^V$$B)PX32=!8/'T``2(/``8#Z+P^V$$@/1-B$
MTG7NBP4X@```2(7M00^5Q(/X_P^$D````(7`#Y7`02'$183D=2-(BT0D"&1(
M*P0E*`````^%L````$B#Q!!;74%<PV8/'T0``(!]``!TU[D$````2(T]02$`
M`$B)WO.F#Y?`'`"$P'6]2(M$)`AD2"L$)2@```!U<4B#Q!!(B>];74%<Z=CC
M__\/'X0``````$B-/:,?``#_%7-_``#I0/___V8/'T0``#'`2(UT)`1(C3TI
M(```Z-7B__](A<!T"P^V`(3`=`0\,'4/QP5K?P```````.E+____QP5<?P``
M`0```.DW_____Q71?0``D$%73(U/.$%6055!5%532('LF`(``&1(BP0E*```
M`$B)A"2(`@``,<!(B>),C90D@````$F)T&8N#Q^$``````!!BP%)BS%)@\`0
M28/!"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(
M2,'F&('A``#_`(GV2`GP2`G(28E`^$TYT'6N2(VR``(```\?@`````!(BT)H
M2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L/3(M?
M$$B+=R!(BU\83(G(3(G*2(MO"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DR)V$B+
M="0(2#'82"'H2(VT,YEY@EI(,=A$C10"2(GJ2(GH2,'H`DC!XAY-B=!("<),
MB=A)P>@;B=%(,<A,(<A,,=A(`?!,B=9(P>8%3`G&1(TT,$R)SDR)R$C!YAY(
MP>@"38GP2`GP2(MT)!!)P>@;2#'"08G%3"'228VT,YEY@EI(,<I(`?),B?9(
MP>8%3`G&1(T$,DR)UDG!Z@)(BU0D&$C!YAY,"=9(C901F7F"6DR)P4@Q\$&)
M]$PA\$PQZ$C!Z1M(`=!,B<)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1002(GP2(M4
M)"!,"?%,B=9(,<A)C905F7F"6DC![AM!B<Y,(<!,,>!(`=!,B=)(P>(%2`GR
M1(TL$$R)PDG!Z`)(BT0D*$C!XAY,B>Y,"<))C80$F7F"6DC![AM(,=%!B=!,
M(=%,,?%(`<%,B>A(P>`%2`GP1(TD`4R)T$G!Z@)(BTPD,$C!X!Y,B>9,"=!)
MC8P.F7F"6D@QPD&)PDPAZDPQPD@!RDR)X4C!X05(P>X;2`GQ3(GN2<'M`DC!
MYAY$C30*2(M4)#A,">Y,B?%(,?!)C900F7F"6DC!Z1M!B?5,(>!,,=!(`=!,
MB?)(P>(%2`G*3(GA2<'L`DC!X1Y$C0002(GP2(M4)$!,">%,B<9(,<A)C902
MF7F"6DC![AM!B<Q,(?!,,>A(`=!,B<)(P>(%2`GR1(T4$$R)\DG![@)(BT0D
M2$C!XAY,B=9,"?))C80%F7F"6DC![AM(,=%!B=9,(<%,,>%(`<%,B=!(P>`%
M2`GP1(TL`4R)P$G!Z`)(BTPD4$C!X!Y,B>Y,"<!)C8P,F7F"6DC![AM(,<)!
MB<!,(=),,?)(`<I,B>E(P>$%2`GQ3(G62<'J`DC!YAY$C20*2(M4)%A,"=9,
MB>%(,?!)C906F7F"6DC!Z1M!B?),(>A,,<!(`=!,B>)(P>(%2`G*3(GI2<'M
M`DC!X1Y$C3002(GP2(M4)&!,">E,B?9(,<A)C900F7F"6DC![AM!B<U,(>!,
M,=!(`=!,B?)(P>(%2`GR1(T$$$R)XDB+1"1H2,'B'DG![`),B<9,">))C80"
MF7F"6DC![AM(,=%!B=1,(?%,,>E(`<%,B<!(P>`%2`GP1(T4`4R)\$G![@)(
MBTPD<$C!X!Y,B=9,"?!)C8P-F7F"6DC![AM(,<)!B<9,(<),,>)(`<I,B=%(
MP>$%2`GQ3(G&2<'H`DC!YAY$C2P*2(M4)'A,"<9,B>E(,?!)C904F7F"6DC!
MZ1M!B?!,(=!,,?!(`=!,B>I(P>(%2`G*3(G12<'J`DC!X1Y$C2002(GP2(N4
M)(````!,"=%,B>9(,<A)C906F7F"6DC![AM!B<I,(>A,,<!(`=!,B>)(P>(%
M2`GR1(TT$$R)ZDG![0)(BX0DB````$C!XAY,B?9,">I)C80`F7F"6DC![AM(
M,=%!B=5,(>%,,=%(`<%,B?!(P>`%2`GP1(T$`4R)X$G![`)(BXPDD````$C!
MX!Y,">!)C8P*F7F"6DV)PD@QPDG!ZAN)QDPA\DPQZD@!RDR)P4C!X05,"=%-
MB?))P>X"2<'B'HG)30GR2`'*2(N,))@```!,,=!!B=1,(<!)C8P-F7F"6DV)
MY4@Q\$G![1M(`<A,B>%(P>$%3`GIB<E(`<A,B<%)P>@"2,'A'D&)Q4P)P4V)
MT$6)TDP#E"2H````23'(1#'"3(N$)*````!.C80&H>O9;DR)[DD!T$R)ZDC!
M[AM(P>(%2`GRB=))`=!,B>))P>P"2,'B'D2)QDP)XDF)S(G)2`.,)+````!)
M,=1$,>!)B?1-C90"H>O9;DB)\$G![!M(P>`%3`G@B<!)`<),B>A)P>T"2,'@
M'D6)U$P)Z$F)U8G223'%13'H38GE2`.4)+@```!.C80!H>O9;DR)X4G![1M(
MP>$%3`GIB<E,`<%)B?!(P>X"2<'@'D&)S4D)\$B)QHG`2`.$),````!,,<9!
M,?)*C;02H>O9;DR)ZDV)ZDG!ZAM(P>(%3`G2B=)(`?),B>9)P>P"2,'F'D&)
MTDP)YDV)Q$6)P$P#A"3(````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@
M!4P)X(G`2`'(3(GI2<'M`DC!X1Y!B<1,">E)B?6)]DDQS40QZDV)Y4V-A!"A
MZ]EN3(GB2,'B!4G![1M(`[0DT````$P)ZHG220'03(G22<'J`DC!XAY%B<5,
M"=))B<J)R4@#C"38````23'21#'038GJ2(VT!J'KV6Y,B>A)P>H;2,'@!4P)
MT(G`2`'&3(G@2<'L`DC!X!Y!B?),">!)B=2)TD@#E"3@````23'$13'@38G4
M3HV$`:'KV6Y,B=%)P>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)
MB<6)P$TQQ40Q[DV)Y4B-M#*AZ]EN3(GB2<'M&TC!X@5,">J)TD@!\DR)UDG!
MZ@)(`X0DZ````$C!YAY!B=5,"=9-B<)%B<!,`X0D\````$DQ\D0QT4V)ZDB-
MC`BAZ]EN3(GH2<'J&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GT
MB?9(`[0D^````$DQS$0QXDV)U$V-A!"AZ]EN3(G22<'L&TC!X@5,">*)TDD!
MT$R)ZDG![0)(P>(>18G$3`GJ28G-B<E),=5$,>A-B>5(C;0&H>O9;DR)X$G!
M[1M(P>`%3`GHB<!(`<9,B=!(P>`>2<'J`D&)]4@#C"0``0``3`G028G2B=)(
M`Y0D"`$``$DQPD4QT$V)ZDZ-A`&AZ]EN3(GI2<'J&TC!X05,"=&)R4P!P4V)
MX$G![`))P>`>08G*30G@28G$B<!(`X0D$`$``$TQQ$0QYDV)U$B-M#*AZ]EN
M3(G22<'L&TC!X@5,">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`23'U
M1#'I38GE2(V,"*'KV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(G12<'J`DC!X1Y!
MB<5,"=%)B?),`X0D&`$``(GV23'*2`.T)"`!``!$,=)-C;00H>O9;DR)ZDV)
MZ$G!Z!M(P>(%3`G"28G(B<E(`XPD*`$``(G220'63(GB2<'L`DC!XAY%B?),
M">)),=!$,<!,C:0&H>O9;DR)T$R)UDC![AM(P>`%2`GP2(G6B=)(`Y0D,`$`
M`(G`20'$3(GH2<'M`DC!X!Y%B>!,">A(,<9!,?9,B<9.C:PQH>O9;DR)P4C!
M[AM(P>$%2`GQB<E)`<U,B=%)P>H"2,'A'D2)[DP)T4F)PHG`23'*13'42`.$
M)#@!``!.C90BH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-
M"<1)B<B)R4TQX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD
M0`$``$6--`!)B?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/
M20'%3`'I38GU3`'A38GT2<'M&TG!Y`5-">Q!`<Q,B=%)P>H"2,'A'DP)T4D)
MR$F)S4&)RDTA\$DA]4T)Z$R+K"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!
MX@5,">I%C2P03(GR2<'N`DC!XAY,"?))B<Y!B=!)"=9-(>9,(<%,"?%,B[0D
M4`$``$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV1(TT,4R)YDG![`)(P>8>
M3`GF2`GR28GTB?%-(<1,(>I,">),BZ0D6`$``$D!Q$T!XDV)]$P!TDV)\DG!
MX@5)P>P;30GB1HTD$DV)ZDG![0))P>(>30GJ28GU1(G230G532'U2"'63`GN
M3(NL)&`!``!)`<5-`>A-B>5,`<9-B>!)P>T;2<'@!4T)Z$:-+`9-B?!)P>X"
M2<'@'DT)\$T)PDV)QD2)QDDAUDTAXDT)\DR+M"1H`0``20'&3`'Q38GN20'*
M3(GI2<'N&TC!X05,"?%%C30*3(GA2<'L`DC!X1Y,">%-B<1)"<Q!B<I-(>Q-
M(=!-">!,BZ0D<`$``$D!Q$P!XDV)]$D!T$R)\DG![!M(P>(%3`GB18TD$$R)
MZDG![0)(P>(>3`GJ2`G128G508G032'53"'Q3`GI3(NL)'@!``!)`<5,`>Y-
MB>5(`?%,B>9)P>T;2,'F!4P)[D2-+#%,B?9)P>X"2,'F'DP)]DF)UHGQ20GV
M32'F2"'*3`GR3(NT)(`!``!)`<9-`?)-B>Y,`=)-B>I)P>X;2<'B!4T)\D:-
M-!)-B>))P>P"2<'B'DT)XDP)UDV)U$2)TDDAS$PA[DP)YDR+I"2(`0``20'$
M30'@38GT3`'&38GP2<'L&TG!X`5-">!&C20&38GH2<'M`DG!X!Y-">A-B=5$
MB<9-"<5-(?5)(?)-">I,BZPDD`$``$D!Q4P!Z4V)Y4D!RDR)X4G![1M(P>$%
M3`GI18TL"DR)\4G![@)(P>$>3`GQ20G(28G.08G*22'V32'@30GP3(NT))@!
M``!)`<9,`?)-B>Y)`=!,B>I)P>X;2,'B!4P)\D6--!!,B>))P>P"2,'B'DP)
MXDF)S$&)T$D)U$TA[$PAP4P)X4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L
M&TC!Y@5,">9$C20Q3(GN2<'M`DC!YAY,">Y("?))B?6)\4TAQ4PA\DP)ZDR+
MK"2H`0``20'%30'J38GE3`'238GB2<'M&TG!X@5-">I&C2P238GR2<'N`DG!
MXAY-"?))B?9$B=)-"=9-(>9((=9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)
MZ$G![AM)P>`%30GP1HTT!DV)X$G![`))P>`>30G@30G"38G$1(G&22'432'J
M30GB3(ND)+@!``!)`<1,`>%-B?1)`<I,B?%)P>P;2,'A!4P)X46-)`I,B>E(
MP>$>2<'M`DP)Z4V)Q4&)RDD)S4TA]4TAT$T)Z$R+K"3``0``20'%3`'J38GE
M20'03(GB2<'M&TC!X@5,">I%C2P03(GR2<'N`DC!XAY,"?)("=%)B=!!B==-
M(=!,(>%,"<%,BX0DR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$
M,4R)YDG![`)(B=%(P>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%(
M`X0DV`$``$D!RDR)P4D!QTP!TDV)PDC!X05)P>H;3`G1B<E(`<I,B>E)P>T"
M2,'A'D&)TDP)Z4R)T$@)SDF)S4C!X`5!B<Y-(>5,(<9,">Y-B=5)P>T;3`'^
M3`GHB<!(`<9,B<!)P>@"2,'@'D&)]4D)P+C6P6+*3#'!,<I(BXPDX`$``$@!
MP4P!X4V)[$@!T4R)ZDG![!M(P>(%3`GBB=)(`=%,B=))P>H"2,'B'D&)S$D)
MTDR)PD6)P$PQTC'62(N4).@!``!(`<))`=9,B>),`?9-B>9(P>(%2<'N&TP)
M\HG23(TT%DR)ZDG![0),B=9(P>(>18GW18G220G52(N4)/`!``!,,>Y(`<(Q
M\4R)_DP!PDC![AM(`=%,B?I(P>(%2`GR2(NT)/@!``")TD@!T4R)XD@!QDG!
M[`)(P>(>3`'638GJ08G(3`GB38G$18GM23'213'63HT4-DR)QDC!Y@5)P>P;
M3`GFB?9)`?),B?Y)P>\"2,'F'D6)U$D)]TB+M"0``@``2`'&3`'N28G5B=)-
M,?U$,>E,C2P.3(GA3(GF2,'N&TC!X05("?%,B<9)P>@"B<E(P>8>20'-2(N,
M)`@"``!,"<9-B?A),?!%B>Y%B?](`<%%,<)(`<I,B?%.C0023(GR2,'I&TC!
MX@5("<I(B?&)]HG220'03(GB2<'L`DC!XAY%B<))"=1(BY0D$`(``$PQX4@!
MPD$QS4R)T4P!^DD!U4R)TDC!Z1M(P>(%2`G*3(GQ2<'N`HG22,'A'DD!U4B+
ME"08`@``3`GQ18GO2`'"2`'R3(GF18GD2#'.03'P3(G^20'03(GZ2,'N&TC!
MX@5("?*)TDD!T$R)TDG!Z@)(P>(>18G&20G22(N4)"`"``!,B?9(P>X;2`'"
M3`'B28G,B<E-,=1%,>5.C20J3(GR2,'B!4@)\DB+M"0H`@``B=))`=1,B?I(
M`<9)P>\"2,'B'D6)Y4P)^D@!\4R)UD6)TD@QUD$Q\$R)[DD!R$R)Z4C![AM(
MP>$%2`GQB<E)`<A,B?%)P>X"2,'A'D6)QTD)SDB+C"0P`@``3(G^2,'N&T@!
MP4P!T4F)THG233'R13'43HT4(4R)^4C!X05("?%,B>Y)P>T"B<E(P>8>20'*
M2(N,)#@"``!,">Y%B=1(`<%(`<I,B?%%B?9(,?%!,<A,B>%)`=!,B>)(P>D;
M2,'B!4@)RDB)\8GVB=))`=!,B?I(P>(>2<'O`D6)Q4D)UTB+E"1``@``3#'Y
M2`'"03'*3(GI3`'R2,'I&TD!TDR)ZDC!X@5("<I,B>%)P>P"B=)(P>$>20'2
M2(N4)$@"``!,">%%B?Q%B=9(`<)(`?),B?Y(,<Y!,?!*C30"3(GR38GP2<'H
M&TC!X@5,"<*)TD@!UDR)ZDG![0)(P>(>08GP20G52(N4)%`"``!(`<),`>))
MB<R)R4TQ[$4QXDZ-)!),B<)-B<))P>H;2,'B!4P)THG220'43(GR2<'N`DC!
MXAY%B>),"?),B[0D6`(``$D!QDP!\4V)[D6)[4DQUD0Q]DV)UD@!SDR)T4G!
M[AM(P>$%3`GQB<E(`<Y,B<%)P>@"2,'A'D&)]DD)R$B+C"1@`@``2`'!20'-
M2(G1B=),,<%!,<Q+C4PE`$V)]$V)]4G![1M)P>0%30GL38G52<'J`DG!Y1Y%
MB>1-">I,BZPD:`(``$P!X4&)S$D!Q4P!ZDV)Q46)P$TQU40Q[DR-+#),B>),
MB>9(P>(%2,'N&T@)\HG220'53(GR2<'N`DC!XAY$B>Y)"=9(BY0D<`(``$@!
MPD@#A"1X`@``3`'"38G033'P1#'!28GP2`'*2(GQ2<'H&TC!X05,"<%%B=`!
MT4R)XDG![`)(P>(>20G42HT4"$B)R$D!T$R)\DC!X`5$`>-,,>)(B5\803'5
M2XT4*$F)R`'I2<'H&TB)3PA,"<`!T$B)!TB)\$C![@)(P>`>2`G&00'S1`-W
M($R)7Q!,B7<@2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?
MP_\5LV<```\?`$B#[`B_@````/\5,6@``+J)J\WON?[<NIB^\.'2PTC'``$C
M16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````
M2(/$",-F9BX/'X0``````$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L
M"$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0``
M`$&#_C\/CC,!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG
M2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HX>C__TPYZW7,
M0<'G!D4I_DECQDB#^`AR7$F+50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@I
MU4DI[4@!Q4B#Y?A(@_T(<AA(@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D
M>$B#Q`A;74%<05U!7D%?PV:0J`1U?$B%P'3A00^V50!!B%0D.*@"=--!#[=4
M!?YFB50%_NO&#Q]``$&]0````$B-?`4`2(G>02G%13GN10].[DUC_4R)^O\5
M;&8``$&+1"1X1`'H08E$)'B#^$!UD4R)YT4I[DP!^^@$Z/__Z<K^__\/'X``
M````28G=Z1O___]!BU4`08E4)#A!BU0%_(E4!?SI4____V8/'X0``````$%6
M3(UV.$%505152(GU4TB+1BA(B?M$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(
MF,9$!CB`2&/!3`'P@_DX#XXL`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S
M2(GOZ&SG__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&($2);7!(B>]$B65T
MZ$+G__](BT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`2,'H"(A#`DB+10"(
M0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"$C!Z`B(0P9(BT4(B$,'2(M%
M$$C!Z!B(0PA(BT402,'H$(A#"4B+11!(P>@(B$,*2(M%$(A#"TB+11A(P>@8
MB$,,2(M%&$C!Z!"(0PU(BT482,'H"(A##DB+11B(0P](BT4@2,'H&(A#$$B+
M12!(P>@0B$,12(M%($C!Z`B(0Q)(BT4@B$,36UU!7$%=05[_);IC``!F+@\?
MA```````NC@````Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A
M^$@IR`'"@^+X@_H(#X+5_O__@^+X,<")QH/`"$B)/#$YT'+SZ;[^___VP@1U
M(X72#X2Q_O__Q@``]L("#X2E_O__,<EFB4P0_NF9_O__#Q\`QP``````QT00
M_`````#I@_[__P\?1```\P\>^D%73(T]PV```$%628G6055)B?5!5$&)_%5(
MC2VT8```4TPI_4B#[`CHW\3__TC!_0-T'S';#Q^``````$R)\DR)[D2)YT'_
M%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0``````/,/'OK#9BX/
M'X0``````)#S#Q[Z2(L-C60``.FPQ/__\P\>^DB#[`A(@\0(PP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`
M)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#4Q`"UE`"TM`````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P``
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#._P````>````H(+__S`!``#`@O__O`4``."$__\8`0``X(7__U@!``"P
MAO__I`$``$"(___H`0``T(C__PP"``"@B?__-`(``)"*__]X`@``X(S__\0"
M``!0C?__W`(``)"-___T`@``8([__R@#``!PCO__/`,``("0__^<`P``L)#_
M_[`#``#0D/__Q`,``("5___P`P```);__PP$```@EO__)`0``#"7__]T!```
M0)___T0%````HO__>`4``$"C___H!0``8+G__S@&``#`N?__4`8``'"[__^<
M!@``<+W__^`&``#@O?__*`<``/"]__]`!P```````!0``````````7I2``%X
M$`$;#`<(D`$``!0````<````P(/__R\`````1`<0`````"0````T````:('_
M_R``````#A!&#AA*#PMW"(``/QH[*C,D(@````!(````7````("$___-````
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)M"@XX1`XP00XH
M0@X@0@X80@X00@X(2`L`0````*@````$A?__C0$```!"#A".`D(.&(T#0@X@
MC`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+"P`@````[```
M`%"&__^,`````$$.$(8"4@ZP`0)Q"@X000X(00LD````$`$``+R&___&````
M`$$.$(8"`EL*#@A,"P)!"@X(00M6#@@`0````#@!``!DA___YP````!"#A"/
M`D<.&(X#0@X@C01"#BB,!40.,(8&40[`(`*&"@XP00XH0@X@0@X80@X00@X(
M1PM(````?`$``!"(__]"`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$
M#CB#!T<.4`,=`0H..$$.,$$.*$(.($(.&$(.$$(."$4+%````,@!```4BO__
M;@````!$#A`"9`X(%````.`!``!LBO__,@````!$#A!7#@@`,````/@!``"4
MBO__Q0````!"#A",`D$.&(8#00X@@P1'#L!``JP*#B!$#AA!#A!"#@A!"Q``
M```L`@``,(O__P4`````````7````$`"```LB___!0(```!"#A"/`D(.&(X#
M0@X@C01%#BB,!4$.,(8&2PXX@P='#O`A`F4*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A#"P*N#O@A2`Z`(F0.^"%!#O`A````$````*`"``#<C/__)0`````````0
M````M`(``/B,__\=`````````"@```#(`@``!(W__Z<$````00X0A@)!#AB#
M`TL.8`-'!`H.&$$.$$$."$$+&````/0"``"(D?__=0````!$#B!M"@X(1PL`
M`!0````0`P``[)'__Q\`````1`X06@X(`$P````H`P``])'__Q`!````0@X0
MC`)!#AB&`TL.((,$1`XP`D(*#B!*#AA!#A!"#@A/"V4*#B!!#AA!#A!"#@A'
M"V0..$D.0&0..$$.,```S````'@#``"TDO__`0@```!"#A"/`D(.&(X#0@X@
MC01,#BB,!4$.,(8&00XX@P='#L"#`@.O`0[(@P)A#M"#`F$.R(,"0@[`@P("
M>PH..$0.,$$.*$(.($(.&$(.$$(."$H+`WH!#LB#`DD.T(,"80[(@P)!#L"#
M`F,.R(,"10[0@P).#MB#`DT.X(,"3`[`@P(#`@$*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A-"P,K`0[(@P)$#M"#`FD.R(,"00[`@P("[`H.R(,"00[0@P)%"S``
M``!(!```])G__[$"````0@X0C0)"#AB,`T$.((8$1`XP`^8!"@X@00X80@X0
M0@X(1`M`````?`0``("<__\_`0```$(.$(P"00X8A@-$#B"#!$0.,`*""@X@
M00X800X00@X(1PMT"@X@1`X800X00@X(30L``"@```#`!```_'S__QX"````
M0@X0C`)!#AB&`T0.4`.P`0H.&$0.$$(."$$+3````.P$``!0G?__'18```!"
M#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`_<5"@XX00XP00XH
M0@X@0@X80@X00@X(00L````4````/`4``""S__]5`````$0.$`)0#@A(````
M5`4``&BS__^G`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.
M0`+E"@XX00XP00XH0@X@0@X80@X00@X(0PL`0````*`%``#,M/__^P$```!"
M#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`TH!"@XH00X@0@X80@X00@X(4`L`
M``````!$````Y`4``(BV__]E`````$8.$(\"20X8C@-%#B"-!$4.*(P%1`XP
MA@9(#CB#!T<.0&X..$$.,$$.*$(.($(.&$(.$$(."``4````+`8``+"V__\%
M```````````````0````1`8``*BV__\0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````4",`````````(P````````$`````````\@(````````!`````````/T"
M`````````0`````````-`P````````\`````````F`0````````,````````
M```@````````#0````````"`6P```````!D`````````P+L````````;````
M``````@`````````&@````````#(NP```````!P`````````"`````````#U
M_O]O``````@#````````!0````````#(#0````````8`````````L`0`````
M```*`````````+L$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````8`````````!0`````````
M!P`````````7`````````%@:````````!P````````#($P````````@`````
M````D`8````````)`````````!@`````````&````````````````````/O_
M_V\``````0``"`````#^__]O`````$@3````````____;P`````"````````
M`/#__V\`````A!(```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3`N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````*@"````````J`(````````<````````````
M`````````0```````````````````!,````'`````@````````#$`@``````
M`,0"````````)`````````````````````0````````````````````F````
M!P````(`````````Z`(```````#H`@```````"`````````````````````$
M````````````````````-````/;__V\"``````````@#````````"`,`````
M``"H`0````````4`````````"````````````````````#X````+`````@``
M``````"P!````````+`$````````&`D````````&`````0````@`````````
M&`````````!&`````P````(`````````R`T```````#(#0```````+L$````
M```````````````!````````````````````3@```/___V\"`````````(02
M````````A!(```````#"``````````4``````````@`````````"````````
M`%L```#^__]O`@````````!($P```````$@3````````@``````````&````
M`@````@```````````````````!J````!`````(`````````R!,```````#(
M$P```````)`&````````!0`````````(`````````!@`````````=`````0`
M``!"`````````%@:````````6!H````````8``````````4````5````"```
M```````8`````````'X````!````!@``````````(``````````@````````
M&P````````````````````0```````````````````!Y`````0````8`````
M````("`````````@(````````"`````````````````````0`````````!``
M````````A`````$````&`````````$`@````````0"````````!`.P``````
M````````````$````````````````````(H````!````!@````````"`6P``
M`````(!;````````#0````````````````````0```````````````````"0
M`````0````(``````````&``````````8````````(`]````````````````
M```0````````````````````F`````$````"`````````("=````````@)T`
M``````#\````````````````````!````````````````````*8````!````
M`@````````"`G@```````(">````````6`8```````````````````@`````
M``````````````"P````#@````,`````````P+L```````#`JP````````@`
M```````````````````(``````````@`````````O`````\````#````````
M`,B[````````R*L````````(````````````````````"``````````(````
M`````,@````&`````P````````#0NP```````-"K````````(`(````````&
M``````````@`````````$`````````#1`````0````,`````````\+T`````
M``#PK0```````!`"```````````````````(``````````@`````````U@``
M``$````#``````````#``````````+`````````@````````````````````
M"````````````````````-P````(`````P`````````@P````````""P````
M````@!```````````````````"````````````````````#A`````0```#``
M```````````````````@L````````!(````````````````````!````````
M``$``````````0````,`````````````````````````,K````````#J````
<`````````````````0``````````````````````
